@@ -304,6 +304,8 @@ extract.bartcFit <-
            combineChains = TRUE,
            ...)
 {
+  issueWarningForUnknownArguments()
+
   if (!is.character(type) || type[1L] %not_in% eval(formals(extract.bartcFit)$type))
     stop("type must be in '", paste0(eval(formals(extract.bartcFit)$type), collapse = "', '"), "'")
   type <- type[1L]
@@ -314,7 +316,7 @@ extract.bartcFit <-
   
   if (type == "p.weights" && is.null(object$p.score))
     stop("p.score cannot be NULL to extract p.weights")
-  
+
   n.chains <- object$n.chains
   if (type == "sigma") {
     if (responseIsBinary(object))
@@ -464,6 +466,8 @@ refit.bartcFit <- function(object, newresp = NULL,
                            commonSup.rule = c("none", "sd", "chisq"),
                            commonSup.cut  = c(NA_real_, 1, 0.05), ...)
 {
+  issueWarningForUnknownArguments()
+
   matchedCall <- match.call()
   if (!is.null(newresp)) warning("'newresp' argument ignored, provided only for generic signature compatibility")
   
@@ -496,7 +500,7 @@ refit.bartcFit <- function(object, newresp = NULL,
   group.by <- if (!is.null(object[["group.by"]])) object[["group.by"]] else NULL
   
   if (object$method.rsp == "bart") {
-    samples.indiv.diff <- extract(object, value = "icate", combineChains = FALSE)
+    samples.indiv.diff <- extract(object, type = "icate", combineChains = FALSE)
     
     object$est <- with(object,
       getEstimateSamples(samples.indiv.diff, treatmentRows, weights, estimand, group.by, group.effects, commonSup.sub))
